@@ -49,6 +49,8 @@ crew_assert <- function(
 #' @param date Date of deprecation.
 #' @param version Package version when deprecation was instated.
 #' @param alternative Message about an alternative.
+#' @param condition Either "warning" or "message" to indicate the type
+#'   of condition thrown on deprecation.
 #' @examples
 #' suppressWarnings(
 #'   crew_deprecate(
@@ -58,7 +60,13 @@ crew_assert <- function(
 #'     alternative = "use the scale argument of push(), pop(), and wait()."
 #'   )
 #' )
-crew_deprecate <- function(name, date, version, alternative) {
+crew_deprecate <- function(
+  name,
+  date,
+  version,
+  alternative,
+  condition = "warning"
+) {
   message <- sprintf(
     "%s was deprecated on %s (crew version %s). Alternative: %s.",
     name,
@@ -66,9 +74,16 @@ crew_deprecate <- function(name, date, version, alternative) {
     version,
     alternative
   )
-  crew_warn(
-    message = message,
-    class = c("crew_deprecate", "crew_warning", "crew")
+  if_any(
+    condition == "warning",
+    crew_warn(
+      message = message,
+      class = c("crew_deprecate", "crew_warning", "crew")
+    ),
+    rlang::inform(
+      message = message,
+      class = c("crew_deprecate", "crew_message", "crew")
+    )
   )
 }
 
