@@ -209,8 +209,21 @@ crew_class_controller_group <- R6::R6Class(
     #'   whereas `substitute = FALSE` is meant for automated R programs
     #'   that invoke `crew` controllers.
     #' @param seed Integer of length 1 with the pseudo-random number generator
-    #'   seed to temporarily set for the evaluation of the task.
-    #'   At the end of the task, the seed is restored.
+    #'   seed to set for the evaluation of the task. Passed to the
+    #'   `seed` argument of `set.seed()` if not `NULL`.
+    #'   If `algorithm` and `seed` are both `NULL`,
+    #'   then the random number generator defaults to the
+    #'   recommended widely spaced worker-specific
+    #'   L'Ecuyer streams as supported by `mirai::nextstream()`.
+    #'   See `vignette("parallel", package = "parallel")` for details.
+    #' @param algorithm Integer of length 1 with the pseudo-random number
+    #'   generator algorithm to set for the evaluation of the task.
+    #'   Passed to the `kind` argument of `RNGkind()` if not `NULL`.
+    #'   If `algorithm` and `seed` are both `NULL`,
+    #'   then the random number generator defaults to the
+    #'   recommended widely spaced worker-specific
+    #'   L'Ecuyer streams as supported by `mirai::nextstream()`.
+    #'   See `vignette("parallel", package = "parallel")` for details.
     #' @param packages Character vector of packages to load for the task.
     #' @param library Library path to load the packages. See the `lib.loc`
     #'   argument of `require()`.
@@ -242,7 +255,8 @@ crew_class_controller_group <- R6::R6Class(
       data = list(),
       globals = list(),
       substitute = TRUE,
-      seed = sample.int(n = 1e9L, size = 1L),
+      seed = NULL,
+      algorithm = NULL,
       packages = character(0),
       library = NULL,
       seconds_timeout = NULL,
@@ -265,6 +279,7 @@ crew_class_controller_group <- R6::R6Class(
         globals = globals,
         substitute = FALSE,
         seed = seed,
+        algorithm = algorithm,
         packages = packages,
         library = library,
         seconds_timeout = seconds_timeout,
@@ -274,12 +289,11 @@ crew_class_controller_group <- R6::R6Class(
         save_command = save_command
       )
     },
-        #' @description Apply a single command to multiple inputs.
+    #' @description Apply a single command to multiple inputs.
     #' @details The idea comes from functional programming: for example,
     #'   the `map()` function from the `purrr` package.
-    #'   The controller must be started and empty before calling `map()`.
-    #' @return A `tibble` of results and metadata, like the output of `pop()`
-    #'   but with multiple rows aggregated together (one row per task).
+    #' @return A `tibble` of results and metadata: one row per task and
+    #'   columns corresponding to the output of `pop()`.
     #' @param command Language object with R code to run.
     #' @param iterate Named list of vectors or lists to iterate over.
     #'   For example, to run function calls
@@ -312,9 +326,22 @@ crew_class_controller_group <- R6::R6Class(
     #'   `substitute = TRUE` is appropriate for interactive use,
     #'   whereas `substitute = FALSE` is meant for automated R programs
     #'   that invoke `crew` controllers.
-    #' @param seed Integer of length 1 with a pseudo-random number generator
-    #'   seed. Task-specific task seeds are non-randomly derived
-    #'   from this seed.
+    #' @param seed Integer of length 1 with the pseudo-random number generator
+    #'   seed to set for the evaluation of the task. Passed to the
+    #'   `seed` argument of `set.seed()` if not `NULL`.
+    #'   If `algorithm` and `seed` are both `NULL`,
+    #'   then the random number generator defaults to the
+    #'   recommended widely spaced worker-specific
+    #'   L'Ecuyer streams as supported by `mirai::nextstream()`.
+    #'   See `vignette("parallel", package = "parallel")` for details.
+    #' @param algorithm Integer of length 1 with the pseudo-random number
+    #'   generator algorithm to set for the evaluation of the task.
+    #'   Passed to the `kind` argument of `RNGkind()` if not `NULL`.
+    #'   If `algorithm` and `seed` are both `NULL`,
+    #'   then the random number generator defaults to the
+    #'   recommended widely spaced worker-specific
+    #'   L'Ecuyer streams as supported by `mirai::nextstream()`.
+    #'   See `vignette("parallel", package = "parallel")` for details.
     #' @param packages Character vector of packages to load for the task.
     #' @param library Library path to load the packages. See the `lib.loc`
     #'   argument of `require()`.
@@ -331,7 +358,11 @@ crew_class_controller_group <- R6::R6Class(
     #' @param error Character vector of length 1, choice of action if
     #'   a task has an error. Possible values:
     #'   * `"stop"`: throw an error in the main R session instead of returning
-    #'     a value.
+    #'     a value. In case of an error, the results from the last errored
+    #'     `map()` are in the `error` field
+    #'     of the controller, e.g. `controller_object$error`. To reduce
+    #'     memory consumption, set `controller_object$error <- NULL` after
+    #'     you are finished troubleshooting.
     #'   * `"warn"`: throw a warning. This allows the return value with
     #'     all the error messages and tracebacks to be generated.
     #'   * `"silent"`: do nothing special.
@@ -346,7 +377,8 @@ crew_class_controller_group <- R6::R6Class(
       data = list(),
       globals = list(),
       substitute = TRUE,
-      seed = as.integer(nanonext::random() / 2),
+      seed = NULL,
+      algorithm = NULL,
       packages = character(0),
       library = NULL,
       seconds_interval = NULL,
@@ -369,6 +401,7 @@ crew_class_controller_group <- R6::R6Class(
         globals = globals,
         substitute = FALSE,
         seed = seed,
+        algorithm = algorithm,
         packages = packages,
         library = library,
         seconds_interval = seconds_interval,
@@ -395,10 +428,9 @@ crew_class_controller_group <- R6::R6Class(
       walk(control, ~.x$collect(throttle = throttle))
     },
     #' @description Pop a completed task from the results data frame.
-    #' @return If there is a completed task available to collect, the return
-    #'   value is a one-row data frame with the results, warnings, and errors.
-    #'   Otherwise, if there are no results available to collect,
-    #'   the return value is `NULL`.
+    #' @return If there is no task to collect, return `NULL`. Otherwise,
+    #'   return a one-row `tibble` with the same columns as `pop()`
+    #'   for ordinary controllers.
     #' @param scale Logical, whether to automatically scale workers to meet
     #'   demand.
     #'   If `TRUE`, then `collect()` runs first
