@@ -1,7 +1,6 @@
 #' @title Evaluate an R command and return results as a monad.
 #' @export
 #' @family utilities
-#' @keywords internal
 #' @description Not a user-side function. Do not call directly.
 #' @details The `crew_eval()` function evaluates an R expression
 #'   in an encapsulated environment and returns a monad with the results,
@@ -10,13 +9,27 @@
 #'   are restored to their original values on exit.
 #' @return A monad object with results and metadata.
 #' @param command Language object with R code to run.
+#' @param name Character of length 1, name of the task.
+#' @param string Character of length 1, string representation of the command.
 #' @param data Named list of local data objects in the evaluation environment.
 #' @param globals Named list of objects to temporarily assign to the
 #'   global environment for the task.
 #' @param seed Integer of length 1 with the pseudo-random number generator
-#'   seed to set for the evaluation of the task. Does not restore
-#'   the original seed, but this is okay because `crew_eval()`
-#'   should only run in a non-interactive worker process.
+#'   seed to set for the evaluation of the task. Passed to the
+#'   `seed` argument of `set.seed()` if not `NULL`.
+#'   If `algorithm` and `seed` are both `NULL`,
+#'   then the random number generator defaults to the
+#'   recommended widely spaced worker-specific
+#'   L'Ecuyer streams as supported by `mirai::nextstream()`.
+#'   See `vignette("parallel", package = "parallel")` for details.
+#' @param algorithm Integer of length 1 with the pseudo-random number
+#'   generator algorithm to set for the evaluation of the task.
+#'   Passed to the `kind` argument of `RNGkind()` if not `NULL`.
+#'   If `algorithm` and `seed` are both `NULL`,
+#'   then the random number generator defaults to the
+#'   recommended widely spaced worker-specific
+#'   L'Ecuyer streams as supported by `mirai::nextstream()`.
+#'   See `vignette("parallel", package = "parallel")` for details.
 #' @param packages Character vector of packages to load for the task.
 #' @param library Library path to load the packages. See the `lib.loc`
 #'   argument of `require()`.
@@ -24,14 +37,28 @@
 #' crew_eval(quote(1 + 1))
 crew_eval <- function(
   command,
+  name = NA_character_,
+  string = NA_character_,
   data = list(),
   globals = list(),
-  seed = as.integer(stats::runif(n = 1L, min = 1, max = 1e9)),
+  seed = NULL,
+  algorithm = NULL,
   packages = character(0),
   library = NULL
 ) {
+  old_algorithm <- RNGkind()[1L]
+  old_seed <- .subset2(.GlobalEnv, ".Random.seed")
+  if (!is.null(algorithm) || !is.null(seed)) {
+    if (!is.null(algorithm)) {
+      RNGkind(kind = algorithm)
+    }
+    if (!is.null(seed)) {
+      set.seed(seed = seed)
+    }
+    on.exit(RNGkind(kind = old_algorithm))
+    on.exit(.GlobalEnv$.Random.seed <- old_seed, add = TRUE)
+  }
   load_packages(packages = packages, library = library)
-  set.seed(seed)
   list2env(x = globals, envir = globalenv())
   envir <- list2env(x = data, parent = globalenv())
   capture_error <- function(condition) {
@@ -65,14 +92,16 @@ crew_eval <- function(
       error = capture_error,
       warning = capture_warning
     ),
-    error = function(condition) NULL
+    error = function(condition) NA
   )
   seconds <- (nanonext::mclock() - start) / 1000
   monad_init(
-    command = deparse_safe(command),
-    result = result %|||% NA,
+    name = name,
+    command = string,
+    result = result,
     seconds = seconds,
-    seed = seed,
+    seed = seed %|||% NA_integer_,
+    algorithm = algorithm %|||% NA_character_,
     error = state$error %|||% NA_character_,
     trace = state$trace %|||% NA_character_,
     warnings = state$warnings %|||% NA_character_,
